@@ -18,8 +18,8 @@ import re
 import trino
 from trino.transaction import IsolationLevel
 import sqlparse
+import os
 
-from dbt.adapters.trino.__version__ import version
 
 logger = AdapterLogger("Trino")
 PREPARED_STATEMENTS_ENABLED_DEFAULT = True
@@ -103,6 +103,7 @@ class TrinoNoneCredentials(TrinoCredentials):
     http_headers: Optional[Dict[str, str]] = None
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
+    retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
 
     @property
     def method(self):
@@ -123,6 +124,7 @@ class TrinoCertificateCredentials(TrinoCredentials):
     http_headers: Optional[Dict[str, str]] = None
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
+    retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
 
     @property
     def http_scheme(self):
@@ -149,6 +151,7 @@ class TrinoLdapCredentials(TrinoCredentials):
     http_headers: Optional[Dict[str, str]] = None
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
+    retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
 
     @property
     def http_scheme(self):
@@ -170,11 +173,15 @@ class TrinoKerberosCredentials(TrinoCredentials):
     host: str
     port: Port
     user: str
-    password: str
+    keytab: Optional[str] = None
+    principal: Optional[str] = None
+    krb5_config: Optional[str] = None
+    service_name: Optional[str] = "trino"
     cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
+    retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
 
     @property
     def http_scheme(self):
@@ -184,8 +191,14 @@ class TrinoKerberosCredentials(TrinoCredentials):
     def method(self):
         return "kerberos"
 
-    def trino_auth():
-        return trino.auth.KerberosAuthentication()
+    def trino_auth(self):
+        os.environ["KRB5_CLIENT_KTNAME"] = self.keytab
+        return trino.auth.KerberosAuthentication(
+            config=self.krb5_config,
+            service_name=self.service_name,
+            principal=self.principal,
+            ca_bundle=self.cert
+        )
 
 
 @dataclass
@@ -198,6 +211,7 @@ class TrinoJwtCredentials(TrinoCredentials):
     http_headers: Optional[Dict[str, str]] = None
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
+    retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
 
     @property
     def http_scheme(self):
@@ -220,6 +234,7 @@ class TrinoOauthCredentials(TrinoCredentials):
     http_headers: Optional[Dict[str, str]] = None
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
+    retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
     OAUTH = trino.auth.OAuth2Authentication(
         redirect_auth_url_handler=trino.auth.WebBrowserRedirectHandler()
     )
@@ -252,7 +267,7 @@ class ConnectionWrapper(object):
         self._prepared_statements_enabled = prepared_statements_enabled
 
     def cursor(self):
-        self._cursor = self.handle.cursor()
+        self._cursor = self.handle.cursor(experimental_python_types=True)
         return self
 
     def cancel(self):
@@ -379,8 +394,9 @@ class TrinoConnectionManager(SQLConnectionManager):
             http_headers=credentials.http_headers,
             session_properties=credentials.session_properties.copy(),
             auth=credentials.trino_auth(),
+            max_attempts=credentials.retries,
             isolation_level=IsolationLevel.AUTOCOMMIT,
-            source=f"dbt-trino-{version}",
+            source="dbt-trino",
         )
         trino_conn._http_session.verify = credentials.cert
         connection.state = "open"
