@@ -177,10 +177,6 @@
   {{ return(load_result('check_schema_exists').table) }}
 {% endmacro %}
 
-{% macro trino__current_timestamp() -%}
-    CURRENT_TIMESTAMP
-{%- endmacro %}
-
 {% macro trino__get_binding_char() %}
   {%- if target.prepared_statements_enabled|as_bool -%}
     {{ return('?') }}
