@@ -3,7 +3,7 @@
     {%- set dest_columns = adapter.get_columns_in_relation(target_relation) -%}
     {%- set dest_cols_csv = dest_columns | map(attribute='quoted') | join(', ') -%}
     insert into {{ target_relation }}
-    select {{dest_cols_csv}} from {{ tmp_relation.include(database=false, schema=false) }};
+    select {{dest_cols_csv}} from {{ tmp_relation.include(database=true, schema=true) }};
 
     drop table if exists {{ tmp_relation }};
 
